use sqlx::PgPool;

use crate::core::*;
use crate::data::Count;
use crate::model::{AccountId, Like, NewLike, NoteId};

pub struct PgLikeDataSource {
    pool: PgPool,
}

impl PgLikeDataSource {
    pub fn new(pool: PgPool) -> PgLikeDataSource {
        PgLikeDataSource { pool }
    }

    pub async fn create(&self, new: NewLike) -> Result<Like> {
        let like: Like = sqlx::query_as(
            "INSERT INTO likes (iri, note_id, account_id)
            VALUES ($1, $2, $3)
            RETURNING *",
        )
        .bind(new.iri)
        .bind(new.note_id)
        .bind(new.account_id)
        .fetch_one(&self.pool)
        .await?;
        Ok(like)
    }

    pub async fn delete(&self, note_id: NoteId, account_id: AccountId) -> Result<()> {
        sqlx::query("DELETE FROM likes WHERE note_id = $1 AND account_id = $2")
            .bind(note_id)
            .bind(account_id)
            .execute(&self.pool)
            .await?;
        Ok(())
    }

    pub async fn count_by_note(&self, note_id: NoteId) -> Result<u64> {
        let result: Count =
            sqlx::query_as("SELECT COUNT(*) as count FROM likes WHERE note_id = $1")
                .bind(note_id)
                .fetch_one(&self.pool)
                .await?;
        Ok(result.count as u64)
    }

    pub async fn by_note_and_account(
        &self,
        note_id: NoteId,
        account_id: AccountId,
    ) -> Result<Like> {
        let like: Like =
            sqlx::query_as("SELECT * FROM likes WHERE note_id = $1 AND account_id = $2")
                .bind(note_id)
                .bind(account_id)
                .fetch_one(&self.pool)
                .await?;
        Ok(like)
    }
}
