use crate::data::memcache::{Indexable, MemCache};
use crate::model::{Note, NoteId};

pub struct MemNoteDataSource {
    cache: MemCache<NoteId, Note>,
}

impl MemNoteDataSource {
    pub fn new() -> MemNoteDataSource {
        MemNoteDataSource {
            cache: MemCache::new(),
        }
    }

    pub async fn by_id(&self, id: NoteId) -> Option<Note> {
        self.cache.get(id).await.map(|arc| arc.as_ref().clone())
    }

    pub async fn store(&self, note: Note) {
        self.cache.put(note).await
    }

    pub async fn delete(&self, id: NoteId) {
        self.cache.del(id).await;
    }
}

impl Indexable<NoteId> for Note {
    fn get_id(&self) -> NoteId {
        self.id
    }
}
