use crate::data::memcache::{Indexable, MemCache};
use crate::model::{Object, ObjectId};

pub struct MemObjectDataSource {
    cache: MemCache<ObjectId, Object>,
}

impl MemObjectDataSource {
    pub fn new() -> MemObjectDataSource {
        MemObjectDataSource {
            cache: MemCache::new(),
        }
    }

    pub async fn by_id(&self, id: ObjectId) -> Option<Object> {
        self.cache.get(id).await.map(|arc| arc.as_ref().clone())
    }

    pub async fn store(&self, obj: Object) {
        self.cache.put(obj).await
    }
}

impl Indexable<ObjectId> for Object {
    fn get_id(&self) -> ObjectId {
        self.id
    }
}
