use sqlx::PgPool;

use crate::core::*;
use crate::model::{NewObject, Object, ObjectId};

pub struct PgObjectDataSource {
    pool: PgPool,
}

impl PgObjectDataSource {
    pub fn new(pool: PgPool) -> PgObjectDataSource {
        PgObjectDataSource { pool }
    }

    pub async fn create(&self, new: NewObject) -> Result<Object> {
        let object: Object = sqlx::query_as(
            "INSERT INTO objects (id, iri, data)
            VALUES ($1, $2, $3)
            RETURNING *",
        )
        .bind(new.id)
        .bind(new.iri)
        .bind(new.data)
        .fetch_one(&self.pool)
        .await?;
        Ok(object)
    }

    pub async fn update(&self, object: &Object) -> Result<()> {
        sqlx::query("UPDATE objects SET data = $1, updated_at = $2 WHERE id = $3")
            .bind(&object.data)
            .bind(&object.updated_at)
            .bind(&object.id)
            .execute(&self.pool)
            .await?;
        Ok(())
    }

    pub async fn by_id(&self, id: ObjectId) -> Result<Object> {
        let object: Object = sqlx::query_as("SELECT * FROM objects WHERE id = $1")
            .bind(id)
            .fetch_one(&self.pool)
            .await?;
        Ok(object)
    }

    pub async fn by_iri(&self, iri: &str) -> Result<Object> {
        let object: Object = sqlx::query_as("SELECT * FROM objects WHERE iri = $1")
            .bind(iri)
            .fetch_one(&self.pool)
            .await?;
        Ok(object)
    }
}
