use crate::data::memcache::{Indexable, MemCache};
use crate::model::{User, UserId};

pub struct MemUserDataSource {
    cache: MemCache<UserId, User>,
}

impl MemUserDataSource {
    pub fn new() -> MemUserDataSource {
        MemUserDataSource {
            cache: MemCache::new(),
        }
    }

    pub async fn by_id(&self, id: UserId) -> Option<User> {
        self.cache.get(id).await.map(|arc| arc.as_ref().clone())
    }

    pub async fn store(&self, user: User) {
        self.cache.put(user).await
    }
}

impl Indexable<UserId> for User {
    fn get_id(&self) -> UserId {
        self.id
    }
}
