use serde;
use sqlx::{Executor, PgPool};

use crate::core::*;
use crate::model::{AccountId, NewUser, User, UserId};

pub struct PgUserDataSource {
    pool: PgPool,
}

impl PgUserDataSource {
    pub fn new(pool: PgPool) -> PgUserDataSource {
        PgUserDataSource { pool }
    }

    pub async fn by_id(&self, id: UserId) -> Result<User> {
        let user: User = sqlx::query_as("SELECT * FROM users WHERE id = $1")
            .bind(id)
            .fetch_one(&self.pool)
            .await?;
        Ok(user)
    }

    pub async fn by_account(&self, account_id: AccountId) -> Result<User> {
        let user: User = sqlx::query_as("SELECT * FROM users WHERE account_id = $1")
            .bind(account_id)
            .fetch_one(&self.pool)
            .await?;
        Ok(user)
    }

    pub async fn by_email(&self, email: &str) -> Result<User> {
        let user: User = sqlx::query_as("SELECT * FROM users WHERE email = $1")
            .bind(email)
            .fetch_one(&self.pool)
            .await?;
        Ok(user)
    }

    pub async fn create(&self, new: NewUser) -> Result<User> {
        let user: User = sqlx::query_as(
            "INSERT INTO users (account_id, email, password, reason, locale, private_key) \
            VALUES ($1, $2, $3, $4, $5, $6) \
            RETURNING *",
        )
        .bind(new.account_id)
        .bind(new.email)
        .bind(new.password)
        .bind(new.reason)
        .bind(new.locale)
        .bind(new.private_key)
        .fetch_one(&self.pool)
        .await?;
        Ok(user)
    }
}
