use chrono::prelude::*;
use serde::Serialize;

use crate::core::*;
use crate::model;
use crate::state::AppState;

/// <https://docs.joinmastodon.org/entities/Account/>
#[derive(Serialize)]
pub struct Account {
    pub id: String,
    pub username: String,
    pub display_name: String,
    pub created_at: DateTime<Utc>,
    pub followers_count: u32,
    pub following_count: u32,
    pub statuses_count: u32,
}

#[derive(Serialize)]
pub struct CredentialAccount {
    #[serde(flatten)]
    pub account: Account,
}

impl Account {
    pub async fn from_model(state: &AppState, model: &model::Account) -> Result<Account> {
        let followers_count = state.repo.follows.follower_count_of(model.id).await?;
        let following_count = state.repo.follows.following_count_of(model.id).await?;
        let statuses_count = state.repo.notes.count_by_account(model.id).await?;
        Ok(Account {
            id: model.id.to_string(),
            username: model.name.clone(),
            display_name: model.display_name.as_ref().unwrap_or(&model.name).clone(),
            created_at: DateTime::from_utc(model.created_at, Utc),
            followers_count,
            following_count,
            statuses_count,
        })
    }
}

impl CredentialAccount {
    pub async fn from_model(state: &AppState, model: &model::Account) -> Result<CredentialAccount> {
        Ok(CredentialAccount {
            account: Account::from_model(state, model).await?,
        })
    }
}
