use chrono::prelude::*;
use serde::Serialize;

use crate::core::*;
use crate::middle::AuthData;
use crate::state::AppState;
use crate::{ent, model};

/// <https://docs.joinmastodon.org/entities/Status/>
#[derive(Serialize)]
pub struct Status {
    pub id: String,
    pub created_at: DateTime<Utc>,
    pub sensitive: bool,
    pub spoiler_text: String,
    pub uri: String,
    pub favourites_count: u64,
    pub favourited: bool,
    pub content: String,
    pub content_type: String,
    pub account: super::Account,
}

impl Status {
    pub async fn from_model(
        state: &AppState,
        model: &model::Note,
        auth: &AuthData,
    ) -> Result<Status> {
        let favourites_count = state.repo.likes.count_by_note(model.id).await?;
        let favourited = match auth.maybe() {
            Some(account) => state
                .repo
                .likes
                .by_note_and_account(model.id, account.id)
                .await
                .is_ok(),
            None => false,
        };
        let author = state.repo.accounts.by_id(model.account_id).await?;
        Ok(Status {
            id: model.id.to_string(),
            created_at: DateTime::from_utc(model.created_at, Utc),
            sensitive: model.sensitive,
            spoiler_text: model.summary.clone().unwrap_or_default(),
            uri: model.iri.clone().unwrap_or_default(),
            favourites_count,
            favourited,
            content: model.content.clone(),
            content_type: model.content_type.clone().unwrap_or_default(),
            account: ent::Account::from_model(state, &author).await?,
        })
    }
}
