use crate::ap::processor::process_document;
use async_trait::async_trait;
use serde::{Deserialize, Serialize};
use std::fmt;

use super::Job;
use crate::core::*;
use crate::state::AppState;

#[derive(Serialize, Deserialize)]
pub struct InboxWorker {
    raw: String,
}

impl InboxWorker {
    pub fn new(raw: String) -> InboxWorker {
        InboxWorker { raw }
    }
}

#[async_trait]
impl Job for InboxWorker {
    async fn perform(&self, state: &AppState) -> Result<()> {
        process_document(state, &self.raw).await
    }

    fn name(&self) -> &'static str {
        "inbox"
    }
}

impl fmt::Debug for InboxWorker {
    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
        write!(f, "ActivityPub ingress: {}", &self.raw)
    }
}
