use chrono::prelude::*;
use serde::{Deserialize, Serialize};
use sqlx::FromRow;

use crate::core::*;
use crate::model::account::AccountId;
use crate::util::validate::{ResultBuilder, Validate};

pub type FollowId = Id<Follow, (AccountId, AccountId)>;

#[derive(Deserialize, Serialize, FromRow)]
pub struct Follow {
    pub iri: Option<String>,
    pub follower_id: AccountId,
    pub followee_id: AccountId,
    pub created_at: NaiveDateTime,
}

pub struct NewFollow {
    pub iri: Option<String>,
    pub follower_id: AccountId,
    pub followee_id: AccountId,
}

impl From<Follow> for FollowId {
    fn from(follow: Follow) -> FollowId {
        (follow.follower_id, follow.followee_id).into()
    }
}

impl Validate for NewFollow {
    fn validate(&self, builder: ResultBuilder) -> ResultBuilder {
        builder
    }
}
