use chrono::prelude::*;
use serde::{Deserialize, Serialize};
use sqlx::FromRow;

use crate::core::*;
use crate::model::{AccountId, NoteId};
use crate::util::validate::{ResultBuilder, Validate};

pub type LikeId = Id<Like, (NoteId, AccountId)>;

#[derive(Clone, Deserialize, Serialize, FromRow)]
pub struct Like {
    pub iri: Option<String>,
    pub note_id: NoteId,
    pub account_id: AccountId,
    pub created_at: NaiveDateTime,
}

pub struct NewLike {
    pub iri: Option<String>,
    pub note_id: NoteId,
    pub account_id: AccountId,
}

impl From<Like> for LikeId {
    fn from(val: Like) -> LikeId {
        (val.note_id, val.account_id).into()
    }
}

impl Validate for NewLike {
    fn validate(&self, builder: ResultBuilder) -> ResultBuilder {
        builder
    }
}
