use sqlx::PgPool;

mod account;
mod follow;
mod like;
mod note;
mod object;
mod user;

pub use account::AccountRepo;
pub use follow::FollowRepo;
pub use like::LikeRepo;
pub use note::NoteRepo;
pub use object::ObjectRepo;
pub use user::UserRepo;

/// The central collection of all data accessible to the app.
/// This is included in `AppState` so it is accessible everywhere.
/// All interactions with resident data must happen through this interface.
pub struct AppRepo {
    pub accounts: AccountRepo,
    pub follows: FollowRepo,
    pub likes: LikeRepo,
    pub notes: NoteRepo,
    pub objects: ObjectRepo,
    pub users: UserRepo,
}

impl AppRepo {
    pub fn new(db_pool: PgPool) -> AppRepo {
        AppRepo {
            accounts: AccountRepo::new(db_pool.clone()),
            follows: FollowRepo::new(db_pool.clone()),
            likes: LikeRepo::new(db_pool.clone()),
            notes: NoteRepo::new(db_pool.clone()),
            objects: ObjectRepo::new(db_pool.clone()),
            users: UserRepo::new(db_pool.clone()),
        }
    }
}
