use actix_web::{post, web, HttpRequest, HttpResponse};

use crate::core::*;
use crate::job::inbox::InboxWorker;
use crate::state::AppState;

#[post("")]
async fn post_inbox(body: String, request: HttpRequest, state: AppState) -> Result<HttpResponse> {
    const CONTENT_TYPES: &[&'static str] = &[
        "application/activity+json",
        "application/ld+json",
        "application/json",
    ];
    let content_type = request
        .headers()
        .get("Content-Type")
        .ok_or(Error::BadRequest)?
        .to_str()?;
    if CONTENT_TYPES.iter().all(|typ| *typ != content_type) {
        return Ok(HttpResponse::BadRequest().finish());
    }

    state.sched.schedule(InboxWorker::new(body));
    Ok(HttpResponse::Ok().finish())
}

pub fn configure(cfg: &mut web::ServiceConfig) {
    cfg.service(post_inbox);
}
