import {LitElement, html, css} from "lit";
import {customElement} from "lit/decorators.js";
import {msg, str} from "@lit/localize";

import {aboutURL, sourceURL, version} from "./config";
import withSharedStyles from "./theme";

import "./components/nav-bar";
import "./features/compose-form";
import "./features/timed-line";
import "./layout/column-layout";
import "./layout/scroll-list";
import "./layout/side-panel";
import {Account, Note} from "./data/types";

@customElement("nyano-blog")
export default class NyanoBlog extends LitElement {
    protected render() {
        return html`
            <column-layout>
                <side-panel slot="left" headline="${msg("Compose")}">
                    <compose-form></compose-form>
                </side-panel>

                <footer slot="left-bottom">
                    <p>
                        ${msg(str`Powered by nyano v${version}`)}
                        <br>
                        <a href="${aboutURL}">${msg("About")}</a>
                        &#183;
                        <a href="${sourceURL}">${msg("Source code")}</a>
                    </p>
                </footer>

                <div id="main-container" slot="main">
                    <nav-bar id="nav"></nav-bar>
                    <timed-line id="tl" .notes=${testNotes}></timed-line>
                    <div class="flex-spacer"></div>
                </div>

                <side-panel slot="right" headline="${msg("Notifications")}">
                    <scroll-list style="max-height: 400px">
                        <p>test uwu</p>
                        <p>test uwu</p>
                        <p>test uwu</p>
                        <p>test uwu</p>
                        <p>test uwu</p>
                        <p>test uwu</p>
                        <p>test uwu</p>
                        <p>test uwu</p>
                        <p>test uwu</p>
                        <p>test uwu</p>
                        <p>test uwu</p>
                        <p>test uwu</p>
                        <p>test uwu</p>
                    </scroll-list>
                </side-panel>

                <div slot="right-bottom">bottom right slot</div>
            </column-layout>
        `;
    }

    static get styles() {
        return withSharedStyles(css`
            footer {
                color: var(--text-faint-color);
            }

            footer a, footer a:visited {
                color: var(--text-faint-color);
            }

            #main-container {
                display: block;
                max-width: 600px;
                margin: auto;
            }

            @media(min-width: 1400px) {
                .flex-spacer, #nav {
                    flex: 1;
                }
                #main-container {
                    display: flex;
                    flex-direction: row;
                    max-width: unset;
                }
                #tl {
                    width: 600px;
                    margin-left: 20px;
                }
            }
        `);
    }
}

const testAccount: Account = {
    id: "1",
    name: "fef",
    domain: "localhost",
    created_at: new Date(),
    updated_at: new Date(),
};

const testNotes: Note[] = [
    {
        id: "1",
        account: testAccount,
        content: "Lorem ipsum dolor sit amet",
        sensitive: false,
        created_at: new Date(),
        updated_at: new Date(),
    },
    {
        id: "2",
        account: testAccount,
        content: "The quick brown fox jumped over the lazy dog.",
        sensitive: false,
        created_at: new Date(),
        updated_at: new Date(),
    },
    {
        id: "3",
        account: testAccount,
        content: "hi i'm gay uwu",
        sensitive: false,
        created_at: new Date(),
        updated_at: new Date(),
    },
    {
        id: "4",
        account: testAccount,
        content: "are there any #Homosexuals #OnHere?",
        sensitive: false,
        created_at: new Date(),
        updated_at: new Date(),
    },
    {
        id: "5",
        account: testAccount,
        content: "test note 1",
        sensitive: false,
        created_at: new Date(),
        updated_at: new Date(),
    },
];
