import {LitElement, html, css} from "lit";
import {customElement, property, state} from "lit/decorators.js";

import withSharedStyles from "../theme";

import "./svg-icon";

@customElement("icon-button")
export default class IconButton extends LitElement {
    @property({type: String, attribute: true})
    public icon = "";

    @property({type: Number, attribute: true})
    public size = 20;

    @property({type: String, attribute: true})
    public color = "var(--text-color)";

    @property({type: String, attribute: true})
    public label = "";

    @property({type: Boolean, attribute: true})
    public disabled = false;

    @state()
    private pressed = false;

    protected render() {
        return html`
            <button
                ?disabled=${this.disabled}
                class="${this.pressed ? "pressed" : ""}"
                @mousedown=${() => this.pressed = true}
                @mouseup=${() => this.pressed = false}
                @mouseleave=${() => this.pressed = false}
                title="${this.label}"
            >
                <svg-icon id="#icon" icon="${this.icon}" color="${this.color}" size="${this.size}"></svg-icon>
            </button>
        `;
    }

    static get styles() {
        return withSharedStyles(css`
            button {
                background-color: transparent;
                border: none;
                box-shadow: none;
                transition: transform var(--anim-duration-short) ease-in-out;
                transform-origin: center;
            }

            button.pressed {
                transform: scale(90%);
            }

            button:not(:disabled):hover {
                cursor: pointer;
            }
        `);
    }
}
