import {LitElement, html, css} from "lit";
import {customElement, property, query} from "lit/decorators.js";

import withSharedStyles from "../theme";

@customElement("input-field")
export default class InputField extends LitElement {
    @query("#input")
    private input: HTMLInputElement;

    @property({type: String})
    public value = "";

    @property({type: String, attribute: true})
    public placeholder = "";

    @property({type: Number, attribute: true})
    public maxlength: number | undefined = undefined;

    protected render() {
        return html`
            <input
                id="input"
                .value="${this.value}"
                placeholder="${this.placeholder}"
                maxlength="${this.maxlength}"
                @input=${() => this.value = this.input.value}
            >
        `;
    }

    static get styles() {
        return withSharedStyles(css`
            :host {
                display: flex;
                flex-direction: row;
                margin: 16px 0;
            }

            input {
                flex: 1;
                display: block;
                font-size: 1rem;
                font-family: var(--font-family);
                color: var(--text-color);
                padding: 8px;
                background-color: var(--background-lighter-color);
                border: none;
                border-radius: var(--border-radius);
                box-shadow: inset 0 1px 1px 0 rgba(255, 255, 255, 0.15);
                transition: box-shadow ease-in-out var(--anim-duration-short);
            }

            input:focus-visible {
                outline: 0;
                box-shadow:
                    inset 0 0 2px 1px var(--accent-highlight-color),
                          0 0 4px 0   var(--accent-highlight-color);
            }
        `);
    }
}
