import {LitElement, html, css} from "lit";
import {customElement} from "lit/decorators.js";
import {msg} from "@lit/localize";

import withSharedStyles from "../theme";

import "./svg-icon";

@customElement("nav-bar")
export default class NavBar extends LitElement {
    protected render() {
        return html`
            <nav>
                <ul>
                    <li aria-current="page">
                        <a href="#">
                            <span class="name">${msg("Home")}</span>
                            <svg-icon size="20" icon="house-fill" role="none"></svg-icon>
                        </a>
                    </li>
                    <li>
                        <a href="#">
                            <span class="name">${msg("Local")}</span>
                            <svg-icon size="20" icon="people-fill" role="none"></svg-icon>
                        </a>
                    </li>
                    <li>
                        <a href="#">
                            <span class="name">${msg("Federated")}</span>
                            <svg-icon size="20" icon="globe-local" role="none"></svg-icon>
                        </a>
                    </li>
                    <li>
                        <a href="#">
                            <span class="name">${msg("Favourites")}</span>
                            <svg-icon size="20" icon="star-fill" role="none"></svg-icon>
                        </a>
                    </li>
                    <li>
                        <a href="#">
                            <span class="name">${msg("Bookmarks")}</span>
                            <svg-icon size="20" icon="bookmark-fill" role="none"></svg-icon>
                        </a>
                    </li>
                    <li>
                        <a href="#">
                            <span class="name">${msg("Settings")}</span>
                            <svg-icon size="20" icon="gear-fill" role="none"></svg-icon>
                        </a>
                    </li>
                </ul>
            </nav>
        `;
    }

    static get styles() {
        return withSharedStyles(css`
            :host {
                font-size: 1.15rem;
            }

            nav {
                display: block;
            }

            ul {
                margin: 0 0 16px;
                padding: 0 0 16px 0;
                list-style-type: none;
                display: block;
                line-height: 20px;
                text-align: center;
                border-bottom: 1px solid rgba(255, 255, 255, 0.4);
            }

            li {
                display: inline-block;
                margin: 0;
                padding: 0 16px;
            }

            a, a:visited {
                color: var(--text-color);
                text-decoration: none;
            }

            li[aria-current] > * {
                color: var(--accent-color);
                font-weight: bold;
                cursor: default;
            }

            svg-icon {
                transform: translateY(3px);
            }

            .name {
                display: none;
            }

            @media(min-width: 1400px) {
                ul {
                    border-bottom: none;
                    border-right: 1px solid rgba(255, 255, 255, 0.2);
                    padding: 0 20px;
                    text-align: right;
                }
                li {
                    display: block;
                    padding: 12px 0;
                }
            }

            @media(min-width: 1700px) {
                .name {
                    display: inline;
                    margin-right: 8px;
                }
            }
        `);
    }
}
