import {LitElement, html, css} from "lit";
import {customElement} from "lit/decorators.js";
import withSharedStyles from "../theme";

@customElement("column-layout")
export default class ColumnLayout extends LitElement {
    protected render() {
        return html`
            <div class="sidebar left">
                <div class="container">
                    <slot name="left"/>
                </div>
                <div class="col-spacer"></div>
                <div class="container">
                    <slot name="left-bottom"/>
                </div>
            </div>

            <div class="main">
                <slot name="main"/>
            </div>

            <div class="sidebar right">
                <div class="container">
                    <slot name="right"/>
                </div>
                <div class="col-spacer"></div>
                <div class="container">
                    <slot name="right-bottom"/>
                </div>
            </div>
        `;
    }

    static get styles() {
        return withSharedStyles(css`
            :host {
                display: flex;
                flex-direction: row;
                padding: 12px;
                height: calc(100vh - 24px);
            }

            .main {
                flex: 1;
            }

            .sidebar {
                display: flex;
                flex-direction: column;
                height: 100%;
            }

            .sidebar.left {
                padding-right: 12px;
            }

            .sidebar.right {
                padding-left: 12px;
            }

            .content {
                display: block;
            }

            .col-spacer {
                flex: 1;
            }
        `);
    }
}
