import {LitElement, html, css} from "lit";
import {customElement, property} from "lit/decorators.js";

import withSharedStyles from "../theme";

/**
 * Container for widgets on the left and right sides of the app.
 * This is not useful on its own; the actual component lives within
 * the slot.  The only thing this does is create a card-like box
 * with a headline.
 */
@customElement("side-panel")
export default class SidePanel extends LitElement {
    @property({type: String, attribute: true})
    public headline = "";

    protected render() {
        return html`
            <h2>${this.headline}</h2>
            <slot/>
        `;
    }

    static get styles() {
        return withSharedStyles(css`
            :host {
                background-color: var(--background-color);
                border-radius: var(--border-radius-large);
                padding: var(--border-radius-large);
                display: block;
                min-width: 300px;
                box-shadow: 0 1px 1px 0 inset rgba(128, 128, 128, 0.15);
                border: 1px solid rgba(255, 255, 255, 0.15);
            }

            h2 {
                margin: 0 0 16px 0;
                line-height: 1.2;
            }
        `);
    }
}
